==> ejc-bfyjerp-api-3.0.0-20241120.022153-44-sources.jar: com/ejianc/business/oa/vo/CertRecordVO.java <==
package com.ejianc.business.oa.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 人力行政-证书档案
 * 
 * @author generator
 * 
 */
public class CertRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String humanTypeName; // 人员类别
    private String humanPayName; // 姓名
    private String phone; // 移动电话
    private Integer sex; // 性别 1：男 2：女
    private String sexName; // 性别 1：男 2：女
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private String idCard; // 身份证号码
    private String major; // 所学专业
    private String educated; // 最高学历
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中

    public String getSexName() {
        return sexName;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    private List<CertRecordDetailVO> certRecordDetailList = new ArrayList<>(); // 人力行政-证书档案-证件信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getHumanPayName() {
        return humanPayName;
    }

    public void setHumanPayName(String humanPayName) {
        this.humanPayName = humanPayName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }
    public String getEducated() {
        return educated;
    }

    public void setEducated(String educated) {
        this.educated = educated;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
     public List<CertRecordDetailVO> getCertRecordDetailList() {
        return certRecordDetailList;
     }

     public void setCertRecordDetailList(List<CertRecordDetailVO> certRecordDetailList) {
        this.certRecordDetailList = certRecordDetailList;
     }
}

==> ejc-bfyjerp-api-3.0.0-20250114.063611-97-sources.jar: com/ejianc/business/oa/vo/CertRecordVO.java <==
package com.ejianc.business.oa.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 人力行政-证书档案
 * 
 * @author generator
 * 
 */
public class CertRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private String humanTypeName; // 人员类别
    private String humanPayName; // 姓名
    private String phone; // 移动电话
    private Integer sex; // 性别 1：男 2：女
    private String sexName; // 性别 1：男 2：女
    private Long orgId; // 组织ID
    private String orgName; // 组织
    private String idCard; // 身份证号码
    private String major; // 所学专业
    private String educated; // 最高学历
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    private Integer humanType; // 人员类别（1内部2外部）
    private Long humanPayId; // 姓名
    public String getSexName() {
        return sexName;
    }

    public Integer getHumanType() {
        return humanType;
    }

    public void setHumanType(Integer humanType) {
        this.humanType = humanType;
    }

    @ReferSerialTransfer(referCode = "bfyj-cert-human")
    public Long getHumanPayId() {
        return humanPayId;
    }
    @ReferDeserialTransfer
    public void setHumanPayId(Long humanPayId) {
        this.humanPayId = humanPayId;
    }

    public void setSexName(String sexName) {
        this.sexName = sexName;
    }

    private List<CertRecordDetailVO> certRecordDetailList = new ArrayList<>(); // 人力行政-证书档案-证件信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getHumanTypeName() {
        return humanTypeName;
    }

    public void setHumanTypeName(String humanTypeName) {
        this.humanTypeName = humanTypeName;
    }
    public String getHumanPayName() {
        return humanPayName;
    }

    public void setHumanPayName(String humanPayName) {
        this.humanPayName = humanPayName;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }
    public String getEducated() {
        return educated;
    }

    public void setEducated(String educated) {
        this.educated = educated;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
     public List<CertRecordDetailVO> getCertRecordDetailList() {
        return certRecordDetailList;
     }

     public void setCertRecordDetailList(List<CertRecordDetailVO> certRecordDetailList) {
        this.certRecordDetailList = certRecordDetailList;
     }
}
